@@ -269,6 +269,7 @@ _DF_FILENAME = "df.parquet.gzip"
 _CONFIG_FILENAME = "config.json"
 _PLACE_KEY = "place"
 _VALIDATION_SIZE = datetime.timedelta(days=365)
+_TEST_SIZE = datetime.timedelta(days=365)
 
 
 class Strategy:
@@ -296,10 +297,11 @@ class Strategy:
             validation_size=_VALIDATION_SIZE,
             max_train_timeout=datetime.timedelta(hours=12),
             cutoff_dt=datetime.datetime.now(tz=pytz.UTC),
-            test_size=datetime.timedelta(days=365 * 2),
+            test_size=_TEST_SIZE,
             allowed_models={"catboost"},
             max_false_positive_reduction_steps=1,
             correlation_chunk_size=5000,
+            insert_null=True,
         )
 
         # Load config
@@ -451,7 +453,11 @@ class Strategy:
         end_dt = start_dt + datetime.timedelta(days=3.0)
         df = df[df[dt_column] > start_dt]
         df = df[df[dt_column] <= end_dt]
-        return df, self._wt.feature_importances(df=df), kelly_ratio
+        return (
+            df,
+            self._wt.feature_importances(df=df, latest_date_only=True),
+            kelly_ratio,
+        )
 
     def _process(self) -> pd.DataFrame:
         df = self.df
